@@ -18,8 +18,8 @@ use crate::{
     crate_metadata::CrateMetadata,
     maybe_println, util, validate_wasm,
     workspace::{Manifest, ManifestPath, Profile, Workspace},
-    BuildArtifacts, BuildMode, BuildResult, OptimizationPasses, OptimizationResult, OutputType,
-    UnstableFlags, UnstableOptions, Verbosity, VerbosityFlags,
+    BuildArtifacts, BuildMode, BuildResult, Network, OptimizationPasses, OptimizationResult,
+    OutputType, UnstableFlags, UnstableOptions, Verbosity, VerbosityFlags,
 };
 use anyhow::{Context, Result};
 use colored::Colorize;
@@ -46,6 +46,7 @@ pub(crate) struct ExecuteArgs {
     pub(crate) manifest_path: ManifestPath,
     verbosity: Verbosity,
     build_mode: BuildMode,
+    network: Network,
     build_artifact: BuildArtifacts,
     unstable_flags: UnstableFlags,
     optimization_passes: OptimizationPasses,
@@ -70,6 +71,9 @@ pub struct BuildCommand {
     /// Then no debug functionality is compiled into the contract.
     #[structopt(long = "--release")]
     build_release: bool,
+    /// Build offline
+    #[structopt(long = "--offline")]
+    build_offline: bool,
     /// Which build artifacts to generate.
     ///
     /// - `all`: Generate the Wasm, the metadata and a bundled `<name>.contract` file.
@@ -149,6 +153,11 @@ impl BuildCommand {
             false => BuildMode::Debug,
         };
 
+        let network = match self.build_offline {
+            true => Network::Offline,
+            false => Network::Online,
+        };
+
         let output_type = match self.output_json {
             true => OutputType::Json,
             false => OutputType::HumanReadable,
@@ -163,6 +172,7 @@ impl BuildCommand {
             manifest_path,
             verbosity,
             build_mode,
+            network,
             build_artifact: self.build_artifact,
             unstable_flags,
             optimization_passes,
@@ -197,6 +207,7 @@ impl CheckCommand {
             manifest_path,
             verbosity,
             build_mode: BuildMode::Debug,
+            network: Network::default(),
             build_artifact: BuildArtifacts::CheckOnly,
             unstable_flags,
             optimization_passes: OptimizationPasses::Zero,
@@ -228,6 +239,7 @@ fn exec_cargo_for_wasm_target(
     crate_metadata: &CrateMetadata,
     command: &str,
     build_mode: BuildMode,
+    network: Network,
     verbosity: Verbosity,
     unstable_flags: &UnstableFlags,
 ) -> Result<()> {
@@ -237,7 +249,7 @@ fn exec_cargo_for_wasm_target(
     // Currently will override user defined RUSTFLAGS from .cargo/config. See https://github.com/paritytech/cargo-contract/issues/98.
     std::env::set_var(
         "RUSTFLAGS",
-        "-C link-arg=-zstack-size=65536 -C link-arg=--import-memory",
+        "-C link-arg=-zstack-size=65536 -C link-arg=--import-memory -Clinker-plugin-lto",
     );
 
     let cargo_build = |manifest_path: &ManifestPath| {
@@ -250,6 +262,9 @@ fn exec_cargo_for_wasm_target(
             "--release",
             &target_dir,
         ];
+        if network == Network::Offline {
+            args.push("--offline");
+        }
         if build_mode == BuildMode::Debug {
             args.push("--features=ink_env/ink-debug");
         } else {
@@ -436,7 +451,6 @@ fn do_optimization(
             We use this tool to optimize the size of your contract's Wasm binary.\n\n\
             wasm-opt is part of the binaryen package. You can find detailed\n\
             installation instructions on https://github.com/WebAssembly/binaryen#tools.\n\n\
-
             There are ready-to-install packages for many platforms:\n\
             * Debian/Ubuntu: apt-get install binaryen\n\
             * Homebrew: brew install binaryen\n\
@@ -625,6 +639,7 @@ pub(crate) fn execute(args: ExecuteArgs) -> Result<BuildResult> {
         manifest_path,
         verbosity,
         build_mode,
+        network,
         build_artifact,
         unstable_flags,
         optimization_passes,
@@ -650,6 +665,7 @@ pub(crate) fn execute(args: ExecuteArgs) -> Result<BuildResult> {
             &crate_metadata,
             "build",
             build_mode,
+            network,
             verbosity,
             &unstable_flags,
         )?;
@@ -680,6 +696,7 @@ pub(crate) fn execute(args: ExecuteArgs) -> Result<BuildResult> {
                 &crate_metadata,
                 "check",
                 BuildMode::Release,
+                network,
                 verbosity,
                 &unstable_flags,
             )?;
@@ -695,6 +712,7 @@ pub(crate) fn execute(args: ExecuteArgs) -> Result<BuildResult> {
             let metadata_result = super::metadata::execute(
                 &crate_metadata,
                 optimization_result.dest_wasm.as_path(),
+                network,
                 verbosity,
                 build_artifact.steps(),
                 &unstable_flags,
@@ -858,6 +876,7 @@ mod tests_ci_only {
                 manifest_path: Some(manifest_path.into()),
                 build_artifact: BuildArtifacts::All,
                 build_release: false,
+                build_offline: false,
                 verbosity: VerbosityFlags::default(),
                 unstable_options: UnstableOptions::default(),
 
@@ -898,6 +917,7 @@ mod tests_ci_only {
                 manifest_path: Some(manifest_path.into()),
                 build_artifact: BuildArtifacts::All,
                 build_release: false,
+                build_offline: false,
                 verbosity: VerbosityFlags::default(),
                 unstable_options: UnstableOptions::default(),
 
@@ -1065,6 +1085,7 @@ mod tests_ci_only {
                 manifest_path: Some(manifest_path.into()),
                 build_artifact: BuildArtifacts::All,
                 build_release: false,
+                build_offline: false,
                 verbosity: VerbosityFlags::default(),
                 unstable_options: UnstableOptions::default(),
                 optimization_passes: None,
